@@ -8,7 +8,7 @@ use Carp ();
 use Amon2::Config::Simple;
 use Amon2::ContextGuard;
 
-our $VERSION = '3.80';
+our $VERSION = '3.81';
 {
     our $CONTEXT; # You can localize this variable in your application.
     sub context { $CONTEXT }
@@ -24,7 +24,7 @@ sub new {
     bless { %args }, $class;
 }
 
-# for CLI
+# For CLI.
 sub bootstrap {
     my $class = shift;
     my $self = $class->new(@_);
@@ -32,7 +32,7 @@ sub bootstrap {
     return $self;
 }
 
-# class method.
+# Class method.
 sub base_dir {
     my $proto = ref $_[0] || $_[0];
     my $base_dir = Amon2::Util::base_dir($proto);
@@ -47,7 +47,7 @@ sub config {
     die "Do not call Amon2->config() directly." if __PACKAGE__ eq $class;
     no strict 'refs';
     my $config = $class->load_config();
-    *{"$class\::config"} = sub { $config }; # class cache.
+    *{"$class\::config"} = sub { $config }; # Class cache.
     return $config;
 }
 
@@ -59,7 +59,7 @@ sub add_config {
     my ($class, $key, $hash) = @_; $hash or Carp::croak("missing args: \$hash");
     Carp::cluck("Amon2->add_config() method was deprecated.");
 
-    # This method will be deprecate.
+    # This method will be deprecated.
     $class->config->{$key} = +{
         %{$class->config->{$key} || +{}},
         %{$hash},
@@ -67,7 +67,7 @@ sub add_config {
 }
 
 # -------------------------------------------------------------------------
-# pluggable things
+# Pluggable things.
 
 sub load_plugins {
     my ($class, @args) = @_;
@@ -85,12 +85,12 @@ sub load_plugin {
 }
 
 # -------------------------------------------------------------------------
-# local context maker
+# Local context maker.
 
 sub make_local_context {
     my $class = shift;
 
-    ## no critic.
+    ## Mo critic.
     eval sprintf(q{
         package %s;
 
@@ -151,7 +151,7 @@ This method returns configuration information. It is generated by C<< MyApp->loa
 
 =item C<< MyApp->mode_name() >>
 
-This is a mode name for Amon2. Default implementation of this method is:
+This is a mode name for Amon2. The default implementation of this method is:
 
     sub mode_name { $ENV{PLACK_ENV} }
 
@@ -169,24 +169,24 @@ Create new context object and set it to global context. When you are writing CLI
 
 =item C<< MyApp->base_dir() >>
 
-This method returns application base directory.
+This method returns the application base directory.
 
 =item C<< MyApp->load_plugin($module_name[, \%config]) >>
 
-This method loads plugin for the application.
+This method loads the plugin for the application.
 
 I<$module_name> package name of the plugin. You can write it as two form like L<DBIx::Class>:
 
     __PACKAGE__->load_plugin("Web::HTTPSession");    # => loads Amon2::Plugin::Web::HTTPSession
 
-If you want to load a plugin in your own name space, use '+' character before package name like following:
+If you want to load a plugin in your own name space, use the '+' character before a package name, like following:
     __PACKAGE__->load_plugin("+MyApp::Plugin::Foo"); # => loads MyApp::Plugin::Foo
 
 =item C<< MyApp->load_plugins($module_name[, \%config ], ...) >>
 
 Load multiple plugins at one time.
 
-If you want to load a plugin in your own name space, use '+' character before package name like following:
+If you want to load a plugin in your own name space, use the '+' character before a package name like following:
 
     __PACKAGE__->load_plugins("+MyApp::Plugin::Foo"); # => loads MyApp::Plugin::Foo
 
@@ -202,7 +202,7 @@ DEPRECATED.
 
 B<((EXPERIMENTAL))>
 
-This method returns boolean value. It returns true when $ENV{AMON2_DEBUG} is true value, false otherwise.
+This method returns a boolean value. It returns true when $ENV{AMON2_DEBUG} is true value, false otherwise.
 
 You can override this method if you need.
 
@@ -212,7 +212,7 @@ You can override this method if you need.
 
 B<THIS MODE IS HIGHLY EXPERIMENTAL>
 
-Normally, Amon2's context is stored in global variable.
+Normally, Amon2's context is stored in a global variable.
 
 This module makes the context to project local.
 
@@ -248,7 +248,7 @@ Shorthand for $MyApp::CONTEXT
 
 =item MyApp->set_context($context)
 
-It's same as:
+It's the same as:
 
     $MyApp::CONTEXT = $context
 
@@ -256,7 +256,7 @@ It's same as:
 
 Create new context guard class.
 
-It's same as:
+It's the same as:
 
     Amon2::ContextGuard->new(shift, \$MyApp::CONTEXT);
 
@@ -268,7 +268,7 @@ More complicated documents are available on L<http://amon.64p.org/>
 
 =head1 SUPPORTS
 
-#amon at irc.perl.org is available.
+#amon at irc.perl.org is also available.
 
 =head1 AUTHOR
 
@@ -277,4 +277,3 @@ Tokuhiro Matsuno E<lt>tokuhirom@gmail.comE<gt>
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
